Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(788)

Unified Diff: chrome/browser/drive/fake_drive_service.h

Issue 881403003: Rename gdata_errorcode.h to drive_api_error_codes.h (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix typos in BUILD.gn Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/drive/fake_drive_service.h
diff --git a/chrome/browser/drive/fake_drive_service.h b/chrome/browser/drive/fake_drive_service.h
index 51d42ac7accca799766ee0cc8fb16c70b16e486c..6d52b677e1688682a69d9dae9f4af71ded6a7d3f 100644
--- a/chrome/browser/drive/fake_drive_service.h
+++ b/chrome/browser/drive/fake_drive_service.h
@@ -54,7 +54,7 @@ class FakeDriveService : public DriveServiceInterface {
// Returns true if the service knows the given drive app id.
bool HasApp(const std::string& app_id) const;
// Changes the offline state. All functions fail with GDATA_NO_CONNECTION
// when offline. By default the offline state is false.
void set_offline(bool offline) { offline_ = offline; }
@@ -310,7 +310,7 @@ class FakeDriveService : public DriveServiceInterface {
const google_apis::FileResourceCallback& callback);
// Sets the user's permission for an entry specified by |resource_id|.
- google_apis::GDataErrorCode SetUserPermission(
+ google_apis::DriveApiErrorCode SetUserPermission(
const std::string& resource_id,
google_apis::drive::PermissionRole user_permission);
@@ -54,7 +54,7 @@ class FakeDriveService : public DriveServiceInterface {
// Returns true if the service knows the given drive app id.
bool HasApp(const std::string& app_id) const;
- // Changes the offline state. All functions fail with GDATA_NO_CONNECTION
+ // Changes the offline state. All functions fail with DRIVE_NO_CONNECTION
// when offline. By default the offline state is false.
void set_offline(bool offline) { offline_ = offline; }

Powered by Google App Engine
This is Rietveld 408576698